==> terraform-0.2.10.tgz: terraform-0.2.10/src/GuiDialogReallyQuit.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _GUI_DIALOG_REALLY_QUIT_H
#define _GUI_DIALOG_REALLY_QUIT_H


#include <gtk--.h>
#include <gtk/gtk.h>

#include "GuiDialogYN.h"


/*
 *  GuiDialogReallyQuit: display the rotate dialog for terraformer
 */
class GuiDialogReallyQuit : public GuiDialogYN
	{
	public: 
				GuiDialogReallyQuit (char *title, char *message); 
				~GuiDialogReallyQuit (); 
		void		fillVBox ();
		void		setLabel (char *s);
		void 		buttonCallbackYes ();
		void 		buttonCallbackNo ();
		Gtk_Button	*getYesButton () { return &(this->d_buttonYes);}
		Gtk_Button	*getNoButton ()  { return &(this->d_buttonNo); }
		bool		yesPressed () 	{ return d_Yes; } 

	private:
		gint 		delete_event_impl (GdkEventAny *);

		bool		d_Yes;
		char		*d_message;
		Gtk_Label	*d_label;
	};


#endif // _GUI_DIALOG_REALLY_QUIT_H

==> terraform-0.2.11.tgz: terraform-0.2.11/src/GuiDialogReallyQuit.h <==
/* Terraform - (C) 1997-1998 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */


#ifndef _GUI_DIALOG_REALLY_QUIT_H
#define _GUI_DIALOG_REALLY_QUIT_H


#include <gtk--.h>
#include <gtk/gtk.h>

#include "GuiDialogYN.h"


/*
 *  GuiDialogReallyQuit: display the rotate dialog for terraformer
 */
class GuiDialogReallyQuit : public GuiDialogYN
	{
	public: 
				GuiDialogReallyQuit (char *title, char *message); 
				~GuiDialogReallyQuit (); 
		void		fillVBox ();
		void		setLabel (char *s);
		void 		buttonCallbackYes ();
		void 		buttonCallbackNo ();
		Gtk_Button	*getYesButton () { return &(this->d_btnYes);}
		Gtk_Button	*getNoButton ()  { return &(this->d_btnNo); }
		bool		yesPressed () 	{ return d_Yes; } 

	private:
		gint 		delete_event_impl (GdkEventAny *);

		bool		d_Yes;
		char		*d_message;
		Gtk_Label	*d_label;
	};


#endif // _GUI_DIALOG_REALLY_QUIT_H
